==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/es_AR.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Compartir entre servidores no está habilitado en este servidor",
    "Uploading..." : "Subiendo...",
    "Cancel" : "Cancelar",
    "Share" : "Compartir",
    "Shared by" : "Compartido por",
    "Sharing" : "Compartiendo",
    "A file or folder has been <strong>shared</strong>" : "Un archivo o carpeta ha sido <strong>compartido</strong>",
    "You shared %1$s with %2$s" : "Has compartido %1$s con %2$s",
    "You shared %1$s with group %2$s" : "Has compartido %1$s en el grupo %2$s",
    "You shared %1$s via link" : "Has compartido %1$s a través del enlace",
    "%2$s shared %1$s with you" : "%2$s compartió %1$s contigo",
    "Shares" : "Compartidos",
    "This share is password-protected" : "Esto está protegido por contraseña",
    "The password is wrong. Try again." : "La contraseña no es correcta. Probá de nuevo.",
    "Password" : "Contraseña",
    "Name" : "Nombre",
    "Expiration date" : "Fecha de vencimiento",
    "Sorry, this link doesn’t seem to work anymore." : "Perdón, este enlace parece no funcionar más.",
    "Reasons might be:" : "Las causas podrían ser:",
    "the item was removed" : "el elemento fue borrado",
    "the link expired" : "el enlace expiró",
    "sharing is disabled" : "compartir está desactivado",
    "For more info, please ask the person who sent this link." : "Para mayor información, contactá a la persona que te mandó el enlace.",
    "Download" : "Descargar",
    "Direct link" : "Vínculo directo"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/files_sharing/l10n/es_AR.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Compartir entre servidores no está habilitado en este servidor",
    "Uploading..." : "Subiendo...",
    "Cancel" : "Cancelar",
    "Share" : "Compartir",
    "Shared by" : "Compartido por",
    "Sharing" : "Compartiendo",
    "A file or folder has been <strong>shared</strong>" : "Un archivo o carpeta ha sido <strong>compartido</strong>",
    "You shared %1$s with %2$s" : "Has compartido %1$s con %2$s",
    "You shared %1$s with group %2$s" : "Has compartido %1$s en el grupo %2$s",
    "You shared %1$s via link" : "Has compartido %1$s a través del enlace",
    "%2$s shared %1$s with you" : "%2$s compartió %1$s contigo",
    "Shares" : "Compartidos",
    "This share is password-protected" : "Esto está protegido por contraseña",
    "The password is wrong. Try again." : "La contraseña no es correcta. Probá de nuevo.",
    "Password" : "Contraseña",
    "Name" : "Nombre",
    "Expiration date" : "Fecha de vencimiento",
    "Sorry, this link doesn’t seem to work anymore." : "Perdón, este enlace parece no funcionar más.",
    "Reasons might be:" : "Las causas podrían ser:",
    "the item was removed" : "el elemento fue borrado",
    "the link expired" : "el enlace expiró",
    "sharing is disabled" : "compartir está desactivado",
    "For more info, please ask the person who sent this link." : "Para mayor información, contactá a la persona que te mandó el enlace.",
    "Download" : "Descargar",
    "Direct link" : "Vínculo directo",
    "Pending" : "Pendientes",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Declined" : "Denegado"
},
"nplurals=2; plural=(n != 1);");
